# REQ02 - Product Requirements

Quản lý yêu cầu sản phẩm: PRD, user stories, acceptance criteria.

## Best Practices

| # | Best Practice | Mô tả |
|---|---------------|-------|
| BP01 | [Writing PRD](REQ02-BP01-Writing-PRD.md) | Viết Product Requirements Document hiệu quả |
| BP02 | [User Stories](REQ02-BP02-User-Stories.md) | Viết user stories và acceptance criteria |

## Tham khảo

- Inspired by Marty Cagan's "Product Requirements"
- User Story Mapping by Jeff Patton
- Agile Product Management with Scrum
